@@ -28,7 +28,7 @@ exchange = None
 container_files_path = None
 
 container_version = "4"
-pypi_version = "0.0.29"
+pypi_version = "0.0.30"
 
 
 def deal_with_stdout():
@@ -570,7 +570,7 @@ async def mythic_service(debug: bool):
     global container_files_path
     connection = None
     container_files_path = pathlib.Path(
-        os.path.abspath(os.path.dirname(__file__))
+        os.path.abspath(os.path.dirname(sys.argv[0]))
     ).parent
     print_flush(f"[*] Importing C2 Profile information")
     import_all_c2_functions()
